summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
diff options
context:
space:
mode:
Diffstat (limited to 'MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c')
-rw-r--r--MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
index 0f83803..37e816a 100644
--- a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
+++ b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
@@ -1157,7 +1157,7 @@ GraphicsConsoleConOutQueryMode (
GRAPHICS_CONSOLE_DEV *Private;
EFI_STATUS Status;
EFI_TPL OldTpl;
-
+
if (ModeNumber >= (UINTN) This->Mode->MaxMode) {
return EFI_UNSUPPORTED;
}
@@ -1280,10 +1280,10 @@ GraphicsConsoleConOutSetMode (
goto Done;
}
//
// Otherwise, the size of the text console and/or the UGA mode will be changed,
// so turn off the cursor, and free the LineBuffer for the current mode
//
- This->EnableCursor (This, FALSE);
+ EraseCursor (This);
FreePool (Private->LineBuffer);
}
@@ -1377,7 +1377,6 @@ GraphicsConsoleConOutSetMode (
// Move the text cursor to the upper left hand corner of the displat and enable it
//
This->SetCursorPosition (This, 0, 0);
- This->EnableCursor (This, TRUE);
Status = EFI_SUCCESS;
@@ -1280,10 +1280,10 @@ GraphicsConsoleConOutSetMode (
}
//
- // Otherwise, the size of the text console and/or the UGA mode will be changed,
- // so turn off the cursor, and free the LineBuffer for the current mode
+ // Otherwise, the size of the text console and/or the GOP/UGA mode will be changed,
+ // so erase the cursor, and free the LineBuffer for the current mode
//